#!/bin/tcsh
echo "DEVICE=eth0" >NET/ifcfg-eth0
echo "BOOTPROTO=static" >>NET/ifcfg-eth0
echo "BROADCAST=128.235.35.255" >>NET/ifcfg-eth0
rm -rf x.temp
egrep `hostname` NET/hosts|awk  '{print $1}' >>x.temp
echo "IPADDR=`cat x.temp`" >>NET/ifcfg-eth0
rm -rf x.temp
echo "NETMASK=255.255.252.0" >>NET/ifcfg-eth0
echo "NETWORK=128.235.32.0" >>NET/ifcfg-eth0
echo "ONBOOT=yes" >>NET/ifcfg-eth0
unalias cp
cp NET/ifcfg-eth0 NET.oth/ifcfg-eth0
