#!/bin/tcsh
# creates /etc/sysconfig/network
rm -rf NET/network
rm -rf NET.oth/network
echo "NETWORKING=yes" >NET/network
echo "HOSTNAME=`hostname`" >>NET/network
echo "#GATEWAY=128.235.32.1" >>NET/network
echo "NETWORKING=yes" >network.tmp
echo "HOSTNAME=`hostname`" >>network.tmp
echo "GATEWAY=128.235.32.1" >>network.tmp
unalias cp
cp  network.tmp NET.oth/network
rm -rf network.tmp
